/**
   @file: im-hwr-plugin.h
                                                                                                           
   Copyright (c) 2004 Nokia. All rights reserved.
                                                                                                           
 */

#ifndef __IM_HWR_PLUGIN_H__
#define __IM_HWR_PLUGIN_H__

#include "im-engines.h"

typedef struct t_IM_HWR_Plugin {
  IM_Status (*Destroy) (void);
  IM_Status (*SetLanguage) (const IM_Locales language, 
                            const HWR_CharacterClass, 
                            HWR_ScriptClass *);
  IM_Status (*GetLanguage) (IM_Locales *language);
  IM_Status (*SetCharacterClass) (HWR_CharacterClass class);
  IM_Status (*GetCharacterClass) (HWR_CharacterClass *class);
  IM_Status (*SetMaxCandidateNum) (const int number);
  IM_Status (*GetMaxCandidateNum) (int *number);
  IM_Status (*SetAndRecognize) (HWR_Points *points, HWR_Results *results);
  IM_Status (*Recognize) (HWR_Results *results);
  IM_Status (*SetInputboxSize) (int x, int y);
  IM_Status (*GetEngineVersion) (char **version);
  IM_Status (*GetDictVersion) (char **version);
  IM_Status (*SetCharOutFlag) (const HWR_Conversion conversion);
  IM_Status (*StartTraining) (void);
  IM_Status (*FinishTraining) (const char*, HWR_Conflicts *);
  IM_Status (*CancelTraining) (void);
  IM_Status (*GetModels) (const char *character, 
                          int *number_of_models, 
                          HWR_Points *strokes);
  IM_Status (*GetLibraryModels) (const char *character, 
                                 int *number_of_models, 
                                 HWR_Points *strokes);
  IM_Status (*GetTrainedCharacters) (HWR_CharacterList *list);
  IM_Status (*DeleteModel) (const char *, int);
  IM_Status (*LoadUserLibrary) (const char *path);
} IM_HWR_Plugin;

IM_Status
SetLanguage(const IM_Locales language,
            const HWR_CharacterClass character_class,
            HWR_ScriptClass *);

IM_Status
GetLanguage(IM_Locales *language);

IM_Status
SetCharacterClass (HWR_CharacterClass class);

IM_Status
GetCharacterClass (HWR_CharacterClass *class);

IM_Status
SetMaxCandidateNum(const int number);

IM_Status
GetMaxCandidateNum(int *number);

IM_Status
Recognize(HWR_Results *results);

IM_Status
SetAndRecognize(HWR_Points *points, HWR_Results *results);

IM_Status
SetInputboxSize(int x, int y);

IM_Status
GetEngineVersion(char **version);

IM_Status
GetDictVersion(char **version);

IM_Status
SetCharOutFlag(const HWR_Conversion conversion);

IM_Status
Destroy (void);

IM_Status
LoadUserLibrary (const char *);

IM_Status 
StartTraining (void);

IM_Status 
FinishTraining (const char*, HWR_Conflicts *);

IM_Status 
CancelTraining (void);

IM_Status 
GetModels (const char *character, int *number_of_models, HWR_Points *strokes);

IM_Status 
GetLibraryModels (const char *character, int *number_of_models, HWR_Points *strokes);

IM_Status 
GetTrainedCharacters (HWR_CharacterList *list);

IM_Status 
DeleteModel (const char *character, int index);

IM_HWR_Plugin*
im_hwr_plugin_init(void);

#endif
