/**
   @file: im-wp-plugin.h
                                                                                                           
   Copyright (c) 2004 Nokia. All rights reserved.
                                                                                                           
 */

#ifndef __IM_WP_PLUGIN_H__
#define __IM_WP_PLUGIN_H__

#include "im-engines.h"

typedef struct t_IM_WP_Plugin {
  IM_Status (*AttachUsedWordsDictionary) (void);
  IM_Status (*AttachPersonalDictionary) (void);
  IM_Status (*AttachDictionary) (IM_Locales language);
  IM_Status (*DetachUsedWordsDictionary) (void);
  IM_Status (*DetachPersonalDictionary) (void);
  IM_Status (*DetachDictionary) (void);
  IM_Status (*GetCandidates) (const char *word, WP_Candidates **candidates, int *number_candidates);
  IM_Status (*SetMaxCandidates) (const int number);
  IM_Status (*GetMaxCandidates) (int *number);
  gboolean  (*WordExistInUsedWordsDictionary) (const char *word);
  gboolean  (*WordExistInPersonalDictionary) (const char *word);
  gboolean  (*WordExistInDictionary) (const char *word);
  IM_Status (*HitWordUsedWordsDictionary) (const char *word);
  IM_Status (*HitWordPersonalDictionary) (const char *word);
  IM_Status (*HitWordDictionary) (const char *word);
  IM_Status (*DeleteWordUsedWordsDictionary) (const char *word);
  IM_Status (*DeleteWordPersonalDictionary) (const char *word);
  IM_Status (*DeleteWordDictionary) (const char *word);
  IM_Status (*AddWordUsedWordsDictionary) (const char *word);
  IM_Status (*AddWordPersonalDictionary) (const char *word);
  IM_Status (*AddWordDictionary) (const char *word);
} IM_WP_Plugin;

IM_WP_Plugin*
im_wp_plugin_init(void);

IM_Status
AttachUsedWordsDictionary(void);

IM_Status
AttachPersonalDictionary(void);

IM_Status
AttachDictionary(IM_Locales language);

IM_Status
DetachUsedWordsDictionary(void);

IM_Status
DetachPersonalDictionary(void);

IM_Status
DetachDictionary(void);

IM_Status
GetCandidates(const char *word, WP_Candidates **candidates, int *number_candidates);

IM_Status
SetMaxCandidates(const int number);

IM_Status
GetMaxCandidates(int *number);

gboolean
WordExistInUsedWordsDictionary(const char *word);

gboolean
WordExistInPersonalDictionary(const char *word);

gboolean
WordExistInDictionary(const char *word);

IM_Status
HitWordUsedWordsDictionary(const char *word);

IM_Status
HitWordPersonalDictionary(const char *word);

IM_Status
HitWordDictionary(const char *word);

IM_Status
DeleteWordUsedWordsDictionary(const char *word);

IM_Status
DeleteWordPersonalDictionary(const char *word);

IM_Status
DeleteWordDictionary(const char *word);

#endif
